using UnityEditor;
using UnityEngine;
using UnityEngine.Events;
using UnityEngine.UIElements;


public class DialogueBox : MonoBehaviour {
    private UIDocument uiDocument;
    [SerializeField] protected VisualTreeAsset visualTree;
    [SerializeField] protected StyleSheet styleSheet;
    [SerializeField] Katas.Experimental.WorldSpaceUIDocument worldSpaceUIDocument;
    private VisualElement root;
    private Button[] buttons;


    public void Awake() {
        worldSpaceUIDocument.onUIDocumentReady.AddListener(setUIDocument);
    }

    private void setUIDocument() {
        uiDocument = GetComponent<UIDocument>();
        root = uiDocument.rootVisualElement;
        VisualElement tree = visualTree.CloneTree();
        tree.styleSheets.Add(styleSheet);
        root.Add(tree);
        buttons = root.Query<Button>().ToList().ToArray();

        for (var i = 0; i < buttons.Length; i++)
        {
            var index = i;
            buttons[i].RegisterCallback<MouseUpEvent>(_ => GetComponent<Storyline>().ApplyTransition(index));
        }

    }

    public void OnEnable() {
        
        SetActor("ActorName");
        SetText("DialogueText");

    }

    public void SetActor(string actor) {
        root.Q<Label>("Actor").text = actor;
    }

    public void SetText(string text) {
        root.Q<TextElement>("Dialogue").text = text;
    }

    public void SetTransitions(Storyline.Transition[] transitions) {
        for(var i = 0; i < buttons.Length; i++) {
            if(i < transitions.Length) {
                buttons[i].visible = true;
                buttons[i].text = transitions[i].transitionText;
            }
            else {
                buttons[i].visible = false;
            }
        }
    }
}



